/*
 * This file is part of Geomajas, a component framework for building
 * rich Internet applications (RIA) with sophisticated capabilities for the
 * display, analysis and management of geographic information.
 * It is a building block that allows developers to add maps
 * and other geographic data capabilities to their web applications.
 *
 * Copyright 2008-2010 Geosparc, http://www.geosparc.com, Belgium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.geomajas.plugin.printing.component;

import java.util.Map;

import org.geomajas.plugin.printing.component.dto.MapComponentInfo;

import com.vividsolutions.jts.geom.Coordinate;

/**
 * Component representing a map.
 * 
 * @author Jan De Moerloose
 *
 * @param <T> DTO object class
 */
public interface MapComponent<T extends MapComponentInfo> extends PrintComponent<T> {

	Coordinate getLocation();

	String getMapId();

	float getPpUnit();

	double getRasterResolution();

	void clearLayers();

	String getApplicationId();

	void setMapId(String mapId);

	void setApplicationId(String applicationId);

	void setLocation(Coordinate mapLocation);

	void setPpUnit(float mapPpUnit);

	void setRasterResolution(double mapRasterResolution);

	void setFilter(Map<String, String> filters);

}